@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 
 #include <QWidget>
 
-namespace GrantleeThemeEditor {
+namespace GrantleeThemeEditor
+{
 class ThemeEditorTabWidget;
 class ThemeSession;
 class DesktopFilePage;
